(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     42789,        938]
NotebookOptionsPosition[     41678,        898]
NotebookOutlinePosition[     42126,        915]
CellTagsIndexPosition[     42083,        912]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Setup", "Section"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Controls`LinearControl`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4565781292194*^9, 3.4565781457086*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"popt", "=", 
   RowBox[{"Sequence", "@@", 
    RowBox[{"{", 
     RowBox[{"plotopt", ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "}"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4572762429496*^9, 3.4572762946792*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"par", "[", 
   RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{
    FractionBox["1", "r1"], "+", 
    FractionBox["1", "r2"]}]]}]], "Input",
 CellChangeTimes->{{3.4579772996651616`*^9, 3.4579773149843616`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lead Compensation", "Section",
 CellChangeTimes->{{3.4579787759243617`*^9, 3.4579787799647617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq", "=", 
  RowBox[{"Together", "[", 
   FractionBox["r3", 
    RowBox[{
     RowBox[{"par", "[", 
      RowBox[{
       RowBox[{"r1", "+", 
        FractionBox["1", 
         RowBox[{"s", " ", "C"}]]}], ",", "r2"}], "]"}], "+", "r3"}]], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pole", "=", 
  RowBox[{"s", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Denominator", "[", "eq", "]"}], "\[Equal]", "0"}], ",", "s"}],
      "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"zero", "=", 
  RowBox[{"s", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Numerator", "[", "eq", "]"}], "\[Equal]", "0"}], ",", "s"}], 
     "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"dcgain", "=", 
  RowBox[{"eq", "/.", 
   RowBox[{"s", "\[Rule]", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"hfgain", "=", 
  RowBox[{"Limit", "[", 
   RowBox[{"eq", ",", 
    RowBox[{"s", "\[Rule]", "\[Infinity]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4579773226127615`*^9, 3.4579774519055614`*^9}, {
  3.457977587048362*^9, 3.4579776318671618`*^9}, {3.4579776878711615`*^9, 
  3.4579777165127616`*^9}, {3.4579778895323615`*^9, 3.457977921683962*^9}, {
  3.4579782119375615`*^9, 3.4579782244799614`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"C", " ", "r1", " ", "s"}], "+", 
     RowBox[{"C", " ", "r2", " ", "s"}]}], ")"}]}], 
  RowBox[{"r2", "+", "r3", "+", 
   RowBox[{"C", " ", "r1", " ", "r2", " ", "s"}], "+", 
   RowBox[{"C", " ", "r1", " ", "r3", " ", "s"}], "+", 
   RowBox[{"C", " ", "r2", " ", "r3", " ", "s"}]}]]], "Output",
 CellChangeTimes->{{3.457977392485162*^9, 3.4579774524359617`*^9}, {
   3.4579775923055615`*^9, 3.4579775998403616`*^9}, 3.4579776321791615`*^9, {
   3.457977703549162*^9, 3.4579777170587616`*^9}, {3.457977890546362*^9, 
   3.4579779221363616`*^9}, {3.457978214324362*^9, 3.4579782250883617`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "r2"}], "-", "r3"}], 
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "+", 
     RowBox[{"r1", " ", "r3"}], "+", 
     RowBox[{"r2", " ", "r3"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.457977392485162*^9, 3.4579774524359617`*^9}, {
   3.4579775923055615`*^9, 3.4579775998403616`*^9}, 3.4579776321791615`*^9, {
   3.457977703549162*^9, 3.4579777170587616`*^9}, {3.457977890546362*^9, 
   3.4579779221363616`*^9}, {3.457978214324362*^9, 3.4579782250883617`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{"r1", "+", "r2"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.457977392485162*^9, 3.4579774524359617`*^9}, {
   3.4579775923055615`*^9, 3.4579775998403616`*^9}, 3.4579776321791615`*^9, {
   3.457977703549162*^9, 3.4579777170587616`*^9}, {3.457977890546362*^9, 
   3.4579779221363616`*^9}, {3.457978214324362*^9, 3.4579782250883617`*^9}}],

Cell[BoxData[
 FractionBox["r3", 
  RowBox[{"r2", "+", "r3"}]]], "Output",
 CellChangeTimes->{{3.457977392485162*^9, 3.4579774524359617`*^9}, {
   3.4579775923055615`*^9, 3.4579775998403616`*^9}, 3.4579776321791615`*^9, {
   3.457977703549162*^9, 3.4579777170587616`*^9}, {3.457977890546362*^9, 
   3.4579779221363616`*^9}, {3.457978214324362*^9, 3.4579782250883617`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"r1", "+", "r2"}], ")"}], " ", "r3"}], 
  RowBox[{
   RowBox[{"r2", " ", "r3"}], "+", 
   RowBox[{"r1", " ", 
    RowBox[{"(", 
     RowBox[{"r2", "+", "r3"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.457977392485162*^9, 3.4579774524359617`*^9}, {
   3.4579775923055615`*^9, 3.4579775998403616`*^9}, 3.4579776321791615`*^9, {
   3.457977703549162*^9, 3.4579777170587616`*^9}, {3.457977890546362*^9, 
   3.4579779221363616`*^9}, {3.457978214324362*^9, 3.4579782250883617`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["zero", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]"}]], "\[Equal]", 
        FractionBox["2.5*^6", "2.5"]}], ",", 
       RowBox[{
        FractionBox["pole", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]"}]], "\[Equal]", "2.5*^6"}], ",", 
       RowBox[{"dcgain", "\[Equal]", 
        FractionBox["1", "2.5"]}], ",", 
       RowBox[{"r3", "\[Equal]", "1*^3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r1", ",", "r2", ",", "r3", ",", "C"}], "}"}]}], "]"}], "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.457977737385562*^9, 3.4579778168675613`*^9}, {
  3.4579778592683616`*^9, 3.4579778666471615`*^9}, {3.4579779982019615`*^9, 
  3.457978023832762*^9}, {3.4579781306303616`*^9, 3.4579781517683616`*^9}, {
  3.4579781834675617`*^9, 3.4579781916107616`*^9}, {3.4579782586283617`*^9, 
  3.457978278939562*^9}, {3.4579783355051613`*^9, 3.4579783361135616`*^9}, {
  3.457978430290762*^9, 3.4579784766539617`*^9}, {3.4579786057751617`*^9, 
  3.457978609269562*^9}, {3.457978651264762*^9, 3.4579786526531615`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"C", "\[Rule]", "1.0610329539459689`*^-10"}], ",", 
    RowBox[{"r1", "\[Rule]", "0"}], ",", 
    RowBox[{"r3", "\[Rule]", "1000.`"}], ",", 
    RowBox[{"r2", "\[Rule]", "1500.`"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.4579778202995615`*^9, {3.457977860563162*^9, 3.4579778672711616`*^9}, {
   3.4579780067507615`*^9, 3.4579780243319616`*^9}, {3.4579781413007617`*^9, 
   3.457978152111562*^9}, 3.457978192141162*^9, {3.4579782306575613`*^9, 
   3.4579782791423616`*^9}, 3.4579783365815616`*^9, 3.4579784338007617`*^9, 
   3.4579784769659615`*^9, 3.4579786095815616`*^9, 3.4579786532459617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"eq", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"s", "/", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", "2.5*^6"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{"s", "/", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", "10*^6"}], ")"}]}]}]]}], "/.", "sol"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "1*^6", "f"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "0.1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4579783399043617`*^9, 3.4579783762367616`*^9}, {
  3.4579785520643616`*^9, 3.457978594948762*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1nk0ldsbB/D3vIZbConKeF6vKaWUEnUN705SEUKEq1K3c2iQ4VdKZUyD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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-2.3025849990109806`, -7.916020700382133},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& )},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {0., 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{{-2.302585092994046, -1.6094379124341003`, \
-0.6931471805599453, 0., 0.6931471805599453, 1.6094379124341003`, 
        2.302585092994046, 2.995732273553991, 
        3.912023005428146, -1.2039728043259361`, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 1.0986122886681098`, 1.3862943611198906`, 
        1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
        2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{-2.3025849990109806`, 
       2.302584999010981}, {-7.916020700382133, 9.07411320766502}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0., 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.995732273553991, 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.912023005428146, 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.2039728043259361`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl13k0Vd0bB3AuKXNlaBAlQ0QqEZGexxT3HvMcoogkNBCRoVRUypTiLaXZ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-2.3025849990109806`, 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& )},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {0., 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{{-2.302585092994046, -1.6094379124341003`, \
-0.6931471805599453, 0., 0.6931471805599453, 1.6094379124341003`, 
        2.302585092994046, 2.995732273553991, 
        3.912023005428146, -1.2039728043259361`, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 1.0986122886681098`, 1.3862943611198906`, 
        1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
        2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{-2.3025849990109806`, 2.302584999010981}, {0., 
       54.90319673394959}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0., 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.995732273553991, 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.912023005428146, 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.2039728043259361`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{369.91999999999973`, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4579783767827616`*^9, 3.4579784367023616`*^9, 3.4579784797115617`*^9, {
   3.4579785953387613`*^9, 3.457978612108762*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{607, 750},
WindowMargins->{{Automatic, 307}, {121, Automatic}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 24, 0, 88, "Section"],
Cell[594, 24, 150, 2, 35, "Input"],
Cell[747, 28, 222, 6, 35, "Input"],
Cell[972, 36, 1452, 39, 256, "Input"],
Cell[2427, 77, 271, 8, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2735, 90, 106, 1, 88, "Section"],
Cell[CellGroupData[{
Cell[2866, 95, 1411, 39, 158, "Input"],
Cell[4280, 136, 696, 14, 54, "Output"],
Cell[4979, 152, 556, 13, 56, "Output"],
Cell[5538, 167, 441, 9, 56, "Output"],
Cell[5982, 178, 372, 6, 53, "Output"],
Cell[6357, 186, 548, 13, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6942, 204, 1202, 28, 117, "Input"],
Cell[8147, 234, 678, 13, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8862, 252, 726, 20, 89, "Input"],
Cell[9591, 274, 32059, 620, 563, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

